from distutils.core import setup
setup(
        name            = 'exerc_nester',
        version         = '1.0.0',
        py_modules		= ['exerc_nester'],
        author          = 'Allef',
        author_email    = 'allef@gmail.com',
        url             = 'http://',
        description     = 'A simple printer of nested lists',
    )
